## SLAM

Stellar LAbel Machine (SLAM) is a forward model to estimate stellar parameters (e.g., Teff, logg, [Fe/H] and chemical abundances).
It is based on Support Vector Regression (SVR), which in essential is a non-parametric regression method.

## Author

Bo Zhang (bozhang@nao.cas.cn)

## Home page

- [https://github.com/hypergravity/astroslam](https://github.com/hypergravity/astroslam)
- [https://pypi.org/project/astroslam/](https://pypi.org/project/astroslam/)

## Install
- for the latest **stable** version:
  - `pip install astroslam`
- for the latest **github** version:
  - `pip install git+git://github.com/hypergravity/astroslam`


## Requirements

- numpy
- scipy
- matplotlib
- astropy
- sklearn
- joblib
- pandas
- emcee
